# atd-utils-args (argutil)
Reusable argument parser for Python scripts

## Installation

```bash
$ pip install atd_argutil
```
## License
As a work of the City of Austin, this project is in the public domain within the United States.

Additionally, we waive copyright and related rights of the work worldwide through the [CC0 1.0 Universal public domain dedication](https://creativecommons.org/publicdomain/zero/1.0/).
